@@ -59,6 +59,9 @@ FAILEDOPERATION_IMAGENUMEXCEED = 'FailedOperation.ImageNumExceed'
 # 图片分辨率过大。
 FAILEDOPERATION_IMAGERESOLUTIONEXCEED = 'FailedOperation.ImageResolutionExceed'
 
+# 图片分辨率过小。
+FAILEDOPERATION_IMAGERESOLUTIONINSUFFICIENT = 'FailedOperation.ImageResolutionInsufficient'
+
 # 未查询到结果。
 FAILEDOPERATION_IMAGESEARCHINVALID = 'FailedOperation.ImageSearchInvalid'
 
@@ -119,6 +122,9 @@ INVALIDPARAMETER_IMAGEFORMATNOTSUPPORT = 'InvalidParameter.ImageFormatNotSupport
 # 参数取值错误。
 INVALIDPARAMETER_INVALIDPARAMETER = 'InvalidParameter.InvalidParameter'
 
+# 图片不可为纯色图。
+INVALIDPARAMETER_PICTURESOLIDCOLORERROR = 'InvalidParameter.PictureSolidColorError'
+
 # 图库简介过长。
 INVALIDPARAMETERVALUE_BRIEFTOOLONG = 'InvalidParameterValue.BriefTooLong'
 
